@@ -2,5 +2,5 @@
 # SPDX-License-Identifier: Apache-2.0
 
 from .app import App
-from .models import Account, Transaction, PaymentUri, Event, KycSample, Payment, PaymentCommand
+from .models import Account, Transaction, PaymentUri, Event, KycSample, Payment, PaymentCommand, RefundReason
 from .falcon import falcon_api
